@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::SourceHutMeta;
 
-our $VERSION = '1.003'; # VERSION
+our $VERSION = '1.004'; # VERSION
 # ABSTRACT: Automatically include SourceHut meta information in META.yml
 
 use strict;
@@ -27,10 +27,9 @@ has 'remote' => (
   default => sub {  [ 'origin' ]  },
 );
 
-has 'issues' => (
+has 'bugtracker' => (
   is  => 'ro',
-  isa => 'Bool',
-  default => 0,
+  isa => 'Maybe[Str]',
 );
 
 has 'user' => (
@@ -126,20 +125,35 @@ sub metadata {
   }
 
   my $srht_url = sprintf 'https://git.sr.ht/~%s/%s', $self->user, $self->repo;
-  my $bug_url = sprintf 'https://todo.sr.ht/~%s/%s', $self->user, $self->repo;
-  my $repo_url = $srht_url;
-
   my $home_url = $self->homepage ? $self->homepage->as_string : $srht_url;
 
+  my $bugtracker;
+  if (!$self->bugtracker && $self->zilla->authors) {
+    $bugtracker = {
+      mailto => $self->zilla->authors->[0]
+    };
+  }
+  elsif ($self->bugtracker eq 'auto') {
+    $bugtracker = {
+      web => sprintf 'https://todo.sr.ht/~%s/%s', $self->user, $self->repo
+    };
+  }
+  else {
+    $bugtracker = {
+      web => $self->bugtracker,
+    }
+  }
+
   return {
     resources => {
       homepage   => $home_url,
       repository => {
         type => 'git',
-        url  => $repo_url,
+        url  => $srht_url,
         web  => $srht_url,
       },
-      bugtracker => ($self->issues ? { web => $bug_url } : { mailto => $self->zilla->authors->[0] }),
+      bugtracker => $bugtracker,
+      foo=>1,
     }
   };
 }
@@ -194,7 +208,7 @@ Dist::Zilla::Plugin::SourceHutMeta - Automatically include SourceHut meta inform
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 SYNOPSIS
 
@@ -237,10 +251,11 @@ inspect.  The first one that looks like a SourceHut remote is used.
 You may override the C<homepage> setting by specifying this attribute. This
 should be a valid URL as understood by L<MooseX::Types::URI>.
 
-=item C<issues>
+=item C<bugtracker>
 
-If true, a bugtracker URL will be added to the distribution metadata for the
-project's SourceHut C<todo> section.
+Define the URL of the SourceHut "ticket tracking service", aka C<todo>, which will be used as the C<bugtracker> value in C<META.json>. Use the special value C<auto> to calculate the bugtracker URL from the repo name. But as SourceHut by default does not provide linking between the code repo (name) and the todo area, you have to make sure that the URL actually exists.
+
+If not set will use the first author as a C<mailto> bugtracker value (because if no value for C<bugtracker> is set, metacpan will link to RT).
 
 =item C<user>
 
